pub struct ReceiveSlot<'a, M: RawMutex, T> { /* private fields */ }Expand description
A slot for receiving in the channel.
The slot is only marked as received when ReceiveSlot::receive_done is called.
Implementations
Sourceimpl<M: RawMutex, T> ReceiveSlot<'_, M, T>
impl<M: RawMutex, T> ReceiveSlot<'_, M, T>
Sourcepub fn receive_done(self)
pub fn receive_done(self)
Notify the channel that the receiving of the value has been finalized.